Learn R Programming

HMC (version 1.1)

extract_lasso_coef: Extract the lasso estimate from the output of anchored_lasso_testing().

Description

Extract the lasso estimate from the output of anchored_lasso_testing().

Usage

extract_lasso_coef(testing_result)

Value

A list, whose elements are the estimated discriminant directions for each split---the length of the output list is the same as n_folds.

The discriminant vectors for each split.

Arguments

testing_result

The output/test result list from anchored_lasso_testing().