Extract the lasso estimate from the output of anchored_lasso_testing().
extract_lasso_coef(testing_result)A list, whose elements are the estimated discriminant directions for each split---the length of the output list is the same as n_folds.
The discriminant vectors for each split.
The output/test result list from anchored_lasso_testing().